@@ -33,10 +33,16 @@
 #  define VTKPVADAPTORSCTH_DEPRECATED_NO_EXPORT VTKPVADAPTORSCTH_NO_EXPORT VTKPVADAPTORSCTH_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef VTKPVADAPTORSCTH_NO_DEPRECATED
 #    define VTKPVADAPTORSCTH_NO_DEPRECATED
 #  endif
 #endif
 
+/* VTK-HeaderTest-Exclude: vtkPVAdaptorsCTHModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
 #endif /* VTKPVADAPTORSCTH_EXPORT_H */
