@@ -1,17 +1,5 @@
-/*=========================================================================
-
-  Program:   ParaView
-  Module:    vtkPVNullSource.h
-
-  Copyright (c) Kitware, Inc.
-  All rights reserved.
-  See Copyright.txt or http://www.paraview.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notice for more information.
-
-=========================================================================*/
+// SPDX-FileCopyrightText: Copyright (c) Kitware Inc.
+// SPDX-License-Identifier: BSD-3-Clause
 /**
  * @class   vtkPVNullSource
  * @brief   source for NULL data.
@@ -19,7 +7,7 @@
  * This is a source for null data. Although this actually produces a
  * vtkPolyLine paraview blocks all data information from this source resulting
  * in it being treated as a null source.
-*/
+ */
 
 #ifndef vtkPVNullSource_h
 #define vtkPVNullSource_h
